# *gc-ims-tools*

Python package to handle and analyze GC-IMS data.
The aim is to implement common data specific routines to fully utilize the existing data science ecosystem for chemometrics.

## Installation

*gc-ims-tools* requieres Python 3.8+ and can be installed with pip:

`pip install gc-ims-tools`

## Documentation

Detailed documentation can be found at: https://charisma-mannheim.github.io/gc-ims-tools/build/html/index.html


## Citation

If this project is helpful for your work citing the following publication would be appreciated:

Christmann, Joscha; Rohn, Sascha; Weller, Philipp (2022): gc-ims-tools – A new Python package for chemometric analysis of GC–IMS data. In: Food chemistry 224 (4), S. 133476. DOI: 10.1016/j.foodchem.2022.133476.
